@@ -7,7 +7,7 @@
 import datetime
 
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from framework.models import BaseModel
 
