@@ -7,10 +7,11 @@
 # @Desc    :
 
 import copy
+import datetime
 from collections.abc import Mapping
 
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from drf_dynamic_fields import DynamicFieldsMixin
 from rest_framework import serializers as s
 from rest_framework.fields import empty, SkipField
@@ -69,11 +70,11 @@ class WritableSerializerReturnDict(ReturnDict):
 class ParamsSerializer(s.Serializer):
     _init_complete = False
 
-    def __init__(self, data=empty, instance=None, *argv, **kwargs):
+    def __init__(self, data=empty, instance=None, valid_exception=True, *argv, **kwargs):
         if isinstance(data, models.Model):
             instance = data
             data = empty
-
+        self.valid_exception = valid_exception
         super().__init__(instance=instance, data=data, *argv, **kwargs)
         self._init_complete = True
 
@@ -116,10 +117,14 @@ class ParamsSerializer(s.Serializer):
     @CacheAttribute
     def data(self):
         if hasattr(self, 'initial_data'):
-            self.is_valid(True)
+            self.is_valid(self.valid_exception)
         ret_data = super().data
         return WritableSerializerReturnDict(ret_data, serializer=self)
 
+    def validation(self):
+        self.initial_data = self.data
+        self.is_valid(True)
+        return self.o
 
     @CachedClassAttribute
     def declared_fields(cls):
@@ -179,7 +184,7 @@ class RecursiveField(s.Serializer):
 
 class BaseModelSerializer(DynamicFieldsMixin, s.ModelSerializer, ParamsSerializer):
     create_datetime = s.DateTimeField(label=_('创建时间'), format=DATETIMEFORMAT, required=False, read_only=False,
-                                      allow_null=True)
+                                      allow_null=True, default=datetime.datetime.now)
     update_datetime = s.DateTimeField(label=_('更新时间'), format=DATETIMEFORMAT, required=False, read_only=True,
                                       allow_null=True)
     _version = s.IntegerField(label=_('内置版本号'), read_only=True, required=False)
